@@ -4,7 +4,7 @@ from typing import Literal, Optional
 from telebox.bot.types.type import Type
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class ForceReply(Type):
     force_reply: Literal[True] = True
     input_field_placeholder: Optional[str] = None
