@@ -4,6 +4,6 @@ from telebox.bot.types.type import Type
 from telebox.bot.types.types.inline_keyboard_button import InlineKeyboardButton
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class InlineKeyboardMarkup(Type):
     inline_keyboard: list[list[InlineKeyboardButton]]
