@@ -4,6 +4,6 @@ from typing import Optional
 from telebox.bot.types.type import Type
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class KeyboardButtonPollType(Type):
     type: Optional[str] = None
