@@ -3,6 +3,6 @@ from dataclasses import dataclass
 from telebox.bot.types.type import Type
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class MessageAutoDeleteTimerChanged(Type):
     message_auto_delete_time: int
