@@ -4,7 +4,7 @@ from telebox.bot.types.type import Type
 from telebox.bot.consts import passport_element_error_sources
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class PassportElementErrorUnspecified(Type):
     type: str
     element_hash: str
