@@ -3,7 +3,7 @@ from dataclasses import dataclass
 from telebox.bot.types.type import Type
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class PollOption(Type):
     text: str
     voter_count: int
