@@ -1,5 +1,6 @@
 from .media_group import MediaGroup
 from .rate_limiter import RateLimit, Limit
+from .router import Router
 from .events import get_event_chat_id, get_event_user_id
 
 
@@ -7,6 +8,7 @@ __all__ = [
     "MediaGroup",
     "RateLimit",
     "Limit",
+    "Router",
     "get_event_chat_id",
     "get_event_user_id"
 ]
