@@ -8,10 +8,18 @@ from telebox.bot.types.types.chat import Chat
 from telebox.dispatcher.enums.media_group_content_type import MediaGroupContentType
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class MediaGroup:
     messages: list[Message]
 
+    def __post_init__(self):
+        self._content_types = set()
+
+        for i in self.messages:
+            self._content_types.add(
+                MediaGroupContentType(i.content_type.value)
+            )
+
     def __iter__(self):
         return iter(self.messages)
 
@@ -29,10 +37,18 @@ class MediaGroup:
     def chat(self) -> Chat:
         return self.messages[0].chat
 
+    @property
+    def message_id(self) -> int:
+        return self.messages[0].message_id
+
     @property
     def message_thread_id(self) -> Optional[int]:
         return self.messages[0].message_thread_id
 
+    @property
+    def message_topic_id(self) -> Optional[int]:
+        return self.messages[0].message_topic_id
+
     @property
     def from_(self) -> Optional[User]:
         return self.messages[0].from_
@@ -83,14 +99,7 @@ class MediaGroup:
 
     @property
     def content_types(self) -> set[MediaGroupContentType]:
-        content_types = set()
-
-        for i in self.messages:
-            _, content_type = i.content
-            content_type = MediaGroupContentType(content_type.value)
-            content_types.add(content_type)
-
-        return content_types
+        return self._content_types
 
     @property
     def date(self) -> datetime:
