@@ -4,13 +4,13 @@ import cherrypy
 import ujson
 
 from telebox.bot.types.types.update import Update
-from telebox.bot.serializer import Serializer
+from telebox.bot.converters import DataclassConverter
 
 
 class ServerRoot:
 
     def __init__(self, update_processor: Callable[[Update], None]):
-        self._serializer = Serializer()
+        self._dataclass_converter = DataclassConverter()
         self._update_processor = update_processor
 
     @cherrypy.expose
@@ -21,7 +21,7 @@ class ServerRoot:
             raise cherrypy.HTTPError(403)
 
         data = ujson.loads(cherrypy.request.body.read(int(content_length)))
-        update = self._serializer.get_object(data=data, class_=Update)
+        update = self._dataclass_converter.get_object(data=data, class_=Update)
         self._update_processor(update)
 
         return str()
